Mailbox

Struct Mailbox 

pub struct Mailbox { /* private fields */ }
Represents an email address, aka “mailbox” in the SMTP spec.

It is composed of a local part and a foreign part. If the address is sent to the Postmaster address for a domain, then the local part will always be converted postmaster, all lowercase. Since the Postmaster address must be handled without regard for case, this makes things simpler.

Implementations

Source

impl Mailbox

pub fn parse(s: &str) -> Result<Mailbox, MailboxParseError>

Creates a Mailbox from a string if the string contains a valid email address. Otherwise, returns a MailboxParseError.

The argument should be of the form: hello@world.com This function does not expect anything to wrap the passed email address. For example, this will result in an error: <hello@world.com>